#ifndef NT2_INCLUDE_FUNCTIONS_IS_INCLUDED_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_INCLUDED_HPP_INCLUDED

#include <nt2/reduction/include/functions/is_included.hpp>

#endif
